@@ -1,12 +1,10 @@
 import os
 import json
-import html
 import simplejson
 import easychart
 import easychart.encoders
-import warnings
 
-from jinja2 import Environment, FileSystemLoader, select_autoescape
+from jinja2 import Environment, FileSystemLoader
 
 #create the environment 
 environment = Environment(
@@ -16,25 +14,15 @@ environment = Environment(
 
 def render(grid):
     #load configuration
-    with open(os.path.join(os.path.dirname(__file__), "config.json"), "r") as file: 
-        config = json.load(file)
-    if os.environ.get("EASYCHART.CONFIG"): 
-        if os.path.exists(os.environ["EASYCHART.CONFIG"]): 
-            with open(os.environ["EASYCHART.CONFIG"], "r") as file: 
-                config.update(json.load(file))
-        else:
-            warnings.warn("Found 'EASYCHART.CONFIG' environment variable, but path does not exist")
-    elif os.path.exists(os.path.expanduser("~/.easychart/config.json")):
-        with open(os.path.expanduser("~/.easychart/config.json"), "r") as file: 
-            config.update(json.load(file))     
+    easychart.config
 
     #determine the theme
     if grid.theme is None: 
         if os.environ.get("EASYCHART.THEME"): 
             grid.theme = os.environ.get("EASYCHART.THEME")
     if grid.theme is None:
-        if config.get("theme") is not None: 
-            grid.theme = config.get("theme")
+        if easychart.config.theme is not None: 
+            grid.theme = easychart.config.theme
     if grid.theme is None:
         if os.path.exists(os.path.expanduser("~/.easychart/theme.json")):
             grid.theme = os.path.expanduser("~/.easychart/theme.json")
@@ -59,8 +47,8 @@ def render(grid):
     template = environment.get_template("template.html")
 
     return template.render(
-            scripts=config["scripts"], 
-            stylesheets=config["stylesheets"],
+            scripts=easychart.config.scripts, 
+            stylesheets=easychart.config.stylesheets,
             theme=simplejson.dumps(grid.theme), 
             plots=simplejson.dumps([plot.serialize() for plot in grid.plots], 
                               default=easychart.encoders.default, ignore_nan=True))
